@@ -94,14 +94,22 @@ class ResourceGroupsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups.html#ResourceGroups.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client/#close)
+        """
+
     def create_group(
         self,
         *,
         Name: str,
         Description: str = ...,
-        ResourceQuery: "ResourceQueryTypeDef" = ...,
+        ResourceQuery: ResourceQueryTypeDef = ...,
         Tags: Mapping[str, str] = ...,
-        Configuration: Sequence["GroupConfigurationItemTypeDef"] = ...
+        Configuration: Sequence[GroupConfigurationItemTypeDef] = ...
     ) -> CreateGroupOutputTypeDef:
         """
         Creates a resource group with the specified name and description.
@@ -182,7 +190,7 @@ class ResourceGroupsClient(BaseClient):
         *,
         GroupName: str = ...,
         Group: str = ...,
-        Filters: Sequence["ResourceFilterTypeDef"] = ...,
+        Filters: Sequence[ResourceFilterTypeDef] = ...,
         MaxResults: int = ...,
         NextToken: str = ...
     ) -> ListGroupResourcesOutputTypeDef:
@@ -197,7 +205,7 @@ class ResourceGroupsClient(BaseClient):
     def list_groups(
         self,
         *,
-        Filters: Sequence["GroupFilterTypeDef"] = ...,
+        Filters: Sequence[GroupFilterTypeDef] = ...,
         MaxResults: int = ...,
         NextToken: str = ...
     ) -> ListGroupsOutputTypeDef:
@@ -209,7 +217,7 @@ class ResourceGroupsClient(BaseClient):
         """
 
     def put_group_configuration(
-        self, *, Group: str = ..., Configuration: Sequence["GroupConfigurationItemTypeDef"] = ...
+        self, *, Group: str = ..., Configuration: Sequence[GroupConfigurationItemTypeDef] = ...
     ) -> Dict[str, Any]:
         """
         Attaches a service configuration to the specified group.
@@ -219,7 +227,7 @@ class ResourceGroupsClient(BaseClient):
         """
 
     def search_resources(
-        self, *, ResourceQuery: "ResourceQueryTypeDef", MaxResults: int = ..., NextToken: str = ...
+        self, *, ResourceQuery: ResourceQueryTypeDef, MaxResults: int = ..., NextToken: str = ...
     ) -> SearchResourcesOutputTypeDef:
         """
         Returns a list of AWS resource identifiers that matches the specified query.
@@ -265,7 +273,7 @@ class ResourceGroupsClient(BaseClient):
         """
 
     def update_group_query(
-        self, *, ResourceQuery: "ResourceQueryTypeDef", GroupName: str = ..., Group: str = ...
+        self, *, ResourceQuery: ResourceQueryTypeDef, GroupName: str = ..., Group: str = ...
     ) -> UpdateGroupQueryOutputTypeDef:
         """
         Updates the resource query of a group.
